@@ -8,9 +8,10 @@ from circle.circle_response import CircleResponse
 
 
 class APIRequestor:
-    def __init__(self, api_key=None, api_base=None, client=None):
+    def __init__(self, api_key=None, api_base=None, client=None, proxy_url=None):
         self.api_base = api_base or circle.api_base
         self.api_key = api_key or circle.api_key
+        self.proxy_url = proxy_url or circle.proxy_url
         if client:
             self._client = client
         elif circle.default_http_client:
@@ -51,6 +52,12 @@ class APIRequestor:
         resp = self.interpret_response(rbody, rcode, rheaders)
         return resp, api_key
 
+    def _get_proxies(self, proxy_url):
+        proxies = None
+        if proxy_url:
+            proxies = {"https": proxy_url}
+        return proxies
+
     def request_raw(self, method, url, params={}, supplied_headers=None):
         if self.api_key:
             api_key = self.api_key
@@ -58,11 +65,15 @@ class APIRequestor:
             from circle import api_key
 
             api_key = api_key
+
         if api_key is None:
 
             # TODO: use custom AuthenticationError exception here
             raise Exception("Invalid api key")
 
+        # best effort to populate proxy_url?
+        proxy_url = self.proxy_url or circle.proxy_url
+
         abs_url = "%s%s" % (self.api_base, url)
 
         if method in (
@@ -82,12 +93,14 @@ class APIRequestor:
             raise Exception("Invalid HTTP method.")
 
         headers = self.request_headers(api_key)
+        proxies = self._get_proxies(proxy_url)
+
         if supplied_headers is not None:
             for key, val in supplied_headers.items():
                 headers[key] = val
 
         rbody, rcode, rheaders = self._client.request_with_retries(
-            method, abs_url, headers, post_data
+            method, abs_url, headers, post_data, proxies
         )
 
         return rbody, rcode, rheaders, api_key
