@@ -20,11 +20,11 @@ class HttpClient:
     def __init__(self):
         self._thread_local = threading.local()
 
-    def request_with_retries(self, method, url, headers, post_data=None):
+    def request_with_retries(self, method, url, headers, post_data=None, proxies=None):
         num_retries = 0
         while True:
             try:
-                response = self.request(method, url, headers, post_data)
+                response = self.request(method, url, headers, post_data, proxies)
                 connection_error = None
             except Exception as e:  # TODO: use custom error
                 response = None
@@ -83,7 +83,7 @@ class RequestsClient(HttpClient):
         self._session = None
         super().__init__(**kwargs)
 
-    def request(self, method, url, headers, post_data=None):
+    def request(self, method, url, headers, post_data=None, proxies=None):
 
         if getattr(self._thread_local, "session", None) is None:
             self._thread_local.session = self._session or requests.Session()
@@ -95,6 +95,7 @@ class RequestsClient(HttpClient):
                 headers=headers,
                 data=post_data,
                 timeout=self._timeout,
+                proxies=proxies,
             )
         except Exception as e:  # TODO: update exception
             raise e
